use serde::Serialize;
use sqlx::PgPool;

#[derive(Serialize)]
pub struct User {
    pub id: uuid::Uuid,
    pub email: String,
    pub admin: bool,
}

use crate::database::model::User as DbUser;
use crate::database::model::UserMember as DbUserMember;
use crate::util::convert_vec;

use super::Member;
impl From<DbUser> for User {
    fn from(db_user: DbUser) -> Self {
        Self {
            id: db_user.user_id,
            email: db_user.email,
            admin: db_user.admin,
        }
    }
}

impl From<User> for DbUser {
    fn from(user: User) -> Self {
        Self {
            user_id: user.id,
            email: user.email,
            admin: user.admin,
            password: None,
        }
    }
}

impl User {
    pub async fn members(&self, pool: &PgPool) -> Result<Vec<Member>, sqlx::Error> {
        let related_members = DbUserMember::get_members_from_user(pool, &self.id).await?;

        Ok(convert_vec(related_members))
    }
}
